package com.ics.admin.service.meeting;

import com.ics.admin.domain.meeting.Showroom;
import com.baomidou.mybatisplus.extension.service.IService;
import java.util.List;

/**
 * 展厅管理Service接口
 * 
 * @author ics
 * @date 2024-03-12
 */
public interface IShowroomService extends IService<Showroom> {
    /**
     * 查询展厅管理
     * 
     * @param id 展厅管理ID
     * @return 展厅管理
     */
    Showroom selectShowroomById(Long id);

    /**
     * 查询展厅管理列表
     * 
     * @param showroom 展厅管理
     * @return 展厅管理集合
     */
    List<Showroom> selectShowroomList(Showroom showroom);

    /**
     * 新增展厅管理
     * 
     * @param showroom 展厅管理
     * @return 结果
     */
    int insertShowroom(Showroom showroom);

    /**
     * 修改展厅管理
     * 
     * @param showroom 展厅管理
     * @return 结果
     */
    int updateShowroom(Showroom showroom);

    /**
     * 批量删除展厅管理
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteShowroomByIds(String ids);

    /**
     * 删除展厅管理信息
     * 
     * @param id 展厅管理ID
     * @return 结果
     */
    int deleteShowroomById(Long id);
}
